@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: idlist.h 1102 2006-12-30 19:39:37Z martin $
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -79,8 +76,9 @@ void GWEN_IdList64_Attach(GWEN_IDLIST64 *idl);
 
 /**
  * Returns a new id list which contains all the ids of the given list
- * in the same order. However, the list returned is compact (i.e. it has no
- * wholes).
+ * in the same order. However, the list returned might be more
+ * is compact (i.e. it has fewer wholes), so the positions of ids
+ * within the list might have changed!.
  */
 GWENHYWFAR_API
 GWEN_IDLIST64 *GWEN_IdList64_dup(const GWEN_IDLIST64 *idl);
@@ -134,8 +132,7 @@ uint64_t GWEN_IdList64_GetNextId(GWEN_IDLIST64 *idl);
  * instead.
  */
 GWENHYWFAR_API DEPRECATED
-uint64_t GWEN_IdList64_GetFirstId2(const GWEN_IDLIST64 *idl,
-                                         uint64_t *hdl);
+uint64_t GWEN_IdList64_GetFirstId2(const GWEN_IDLIST64 *idl, uint64_t *hdl);
 
 /**
  * @deprecated
@@ -143,8 +140,7 @@ uint64_t GWEN_IdList64_GetFirstId2(const GWEN_IDLIST64 *idl,
  * instead.
  */
 GWENHYWFAR_API DEPRECATED
-uint64_t GWEN_IdList64_GetNextId2(const GWEN_IDLIST64 *idl,
-                                        uint64_t *hdl);
+uint64_t GWEN_IdList64_GetNextId2(const GWEN_IDLIST64 *idl, uint64_t *hdl);
 
 
 /**
@@ -168,6 +164,9 @@ GWENHYWFAR_API
 uint64_t GWEN_IdList64_GetIdAt(const GWEN_IDLIST64 *idl, uint64_t index);
 
 
+GWENHYWFAR_API
+uint64_t GWEN_IdList64_GetEntryCount(const GWEN_IDLIST64 *idl);
+
 /*@}*/
 
 
