@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Thu Apr 03 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -30,6 +27,9 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
+
 #include <gwenhywfar/gwenhywfarapi.h>
 #include <gwenhywfar/misc.h>
 #include "stringlist_p.h"
@@ -147,6 +147,41 @@ void GWEN_StringList_AppendEntry(GWEN_STRINGLIST *sl,
 
 
 
+GWEN_STRINGLIST *GWEN_StringList_fromTabString(const char *s, int checkDup) {
+  GWEN_STRINGLIST *sl;
+
+  sl=GWEN_StringList_new();
+  if (s && *s) {
+    while(*s) {
+      const char *t;
+      char *tmpStr;
+  
+      t=strchr(s, '\t');
+      if (t) {
+	int len;
+  
+	len=(t-s);
+	tmpStr=(char*) malloc(len+1);
+	assert(tmpStr);
+	memmove(tmpStr, s, len);
+	tmpStr[len]=0;
+	/* add partial string, take it over */
+	GWEN_StringList_AppendString(sl, tmpStr, 1, checkDup);
+	s=t+1;
+      }
+      else {
+	/* just add the remaining string (don't take over, copy!) */
+	GWEN_StringList_AppendString(sl, s, 0, checkDup);
+	break;
+      }
+    }
+  }
+
+  return sl;
+}
+
+
+
 void GWEN_StringList_RemoveEntry(GWEN_STRINGLIST *sl,
 				 GWEN_STRINGLISTENTRY *se){
   GWEN_STRINGLISTENTRY *curr;
@@ -368,6 +403,38 @@ int GWEN_StringList_HasString(const GWEN_STRINGLIST *sl,
 
 
 
+int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s){
+  GWEN_STRINGLISTENTRY *se;
+  int i;
+
+  assert(sl);
+  se=sl->first;
+  if (sl->senseCase) {
+    i=0;
+    while(se) {
+      if (strcmp(se->data, s)==0) {
+	return i;
+      }
+      i++;
+      se=se->next;
+    } /* while */
+    return -1;
+  }
+  else {
+    i=0;
+    while(se) {
+      if (strcasecmp(se->data, s)==0) {
+	return i;
+      }
+      i++;
+      se=se->next;
+    } /* while */
+    return -1;
+  }
+}
+
+
+
 GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl){
   GWEN_STRINGLISTENTRY *se;
   GWEN_STRINGLIST *newsl;
