@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
     begin       : Wed Mar 16 2005
     copyright   : (C) 2005 by Martin Preuss
     email       : martin@libchipcard.de
@@ -15,6 +12,9 @@
 #endif
 
 
+#define DISABLE_DEBUGLOG
+
+
 #include "mdigestgc_p.h"
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
