@@ -35,7 +35,6 @@ struct GWEN_GUI_CGUI {
 
   uint32_t nextBoxId;
   uint32_t nextProgressId;
-  char *charSet;
 
   GWEN_GUI_CHECKCERT_FN checkCertFn;
   GWEN_DB_NODE *dbPasswords;
@@ -52,12 +51,6 @@ void GWENHYWFAR_CB GWEN_Gui_CGui_FreeData(void *bp, void *p);
 
 
 
-int GWEN_Gui_CGui__ConvertFromUtf8(GWEN_GUI *gui,
-				   const char *text,
-				   int len,
-				   GWEN_BUFFER *tbuf);
-
-
 char GWEN_Gui_CGui__readCharFromStdin(int waitFor);
 int GWEN_Gui_CGui__input(GWEN_GUI *gui,
 			 uint32_t flags,
@@ -127,7 +120,7 @@ int GWEN_Gui_CGui__HashPassword(const char *token,
 
 int GWEN_Gui_CGui_CheckCert(GWEN_GUI *gui,
 			    const GWEN_SSLCERTDESCR *cd,
-			    GWEN_IO_LAYER *io, uint32_t guiid);
+			    GWEN_SYNCIO *sio, uint32_t guiid);
 
 int GWEN_Gui_CGui_SetPasswordStatus(GWEN_GUI *gui,
 				    const char *token,
