@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: error.h 1104 2007-01-03 09:21:32Z martin $
     begin       : Tue Oct 02 2002
-    copyright   : (C) 2002 by Martin Preuss
+    copyright   : (C) 2002-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -34,7 +31,8 @@
 #include <gwenhywfar/logger.h>
 #include <gwenhywfar/inetsocket.h>
 #include <gwenhywfar/ssl_cert_descr.h>
-#include <gwenhywfar/iolayer.h>
+#include <gwenhywfar/syncio.h>
+#include <gwenhywfar/dialog.h>
 
 #include <inttypes.h>
 
@@ -50,7 +48,7 @@
  * The GWEN_GUI object contains callbacks for message display, user
  * input, progress reports, SSL certificate checking etc.
  *
- * There are implementations of GWEN_GUI based on console, QT3 and FOX.
+ * There are implementations of GWEN_GUI based on console, QT3, QT4 and FOX.
  *
  * GWEN_GUI uses flags to tell implementations what the caller needs of the GUI
  * implementation.
@@ -185,7 +183,7 @@ GWEN_INHERIT_FUNCTION_LIB_DEFS(GWEN_GUI, GWENHYWFAR_API)
  *  </li>
  * </ul>
  * <p>
- * A note about <i>confirmation buttons</i>: AqBanking has been designed with
+ * A note about <i>confirmation buttons</i>: Gwenhywfar has been designed with
  * non-interactive applications in mind. For such an application it is
  * important to know what button-press it has to simulate upon catching of a
  * messagebox callback. This is what the confimation button flags are for.
@@ -245,8 +243,8 @@ GWEN_INHERIT_FUNCTION_LIB_DEFS(GWEN_GUI, GWENHYWFAR_API)
  * The backend calling this function thus allows the frontend to detect
  * when the message is important regarding data security.
  * E.g. a message like "Shall I delete this file" should be considered
- * dangerous (since this might result in a data loss). However, the messae
- * "Just started" is not that dangerous ;-)
+ * dangerous (since this might result in a data loss). However, the message
+ * "Application started" is not that dangerous ;-)
  * </p>
  * <p>
  * The following example allows to determine whether a message is
@@ -350,6 +348,23 @@ GWEN_GUI *GWEN_Gui_GetGui();
 
 
 
+/** @name Character Set
+ *
+ * All messages and texts can be converted from UTF8 automatically.
+ * This needs the name of the destination character set.
+ * See output of <i>iconv --list</i> for a list of supported
+ * character sets.
+ */
+/*@{*/
+GWENHYWFAR_API 
+const char *GWEN_Gui_GetCharSet(const GWEN_GUI *gui);
+
+GWENHYWFAR_API 
+void GWEN_Gui_SetCharSet(GWEN_GUI *gui, const char *s);
+/*@}*/
+
+
+
 
 
 
@@ -429,6 +444,15 @@ int GWEN_Gui_MessageBox(uint32_t flags,
 			const char *b3,
 			uint32_t guiid);
 
+/**
+ * This is a convenience function which calls @ref GWEN_Gui_MessageBox showing the given
+ * message and a single "Close" button.
+ * It is especially well suited to show an error message.
+ */
+GWENHYWFAR_API 
+void GWEN_Gui_ShowError(const char *title, const char *text, ...);
+
+
 /**
  * <p>
  * Ask the user for input.
@@ -581,6 +605,23 @@ int GWEN_Gui_ProgressLog(uint32_t id,
 			 GWEN_LOGGER_LEVEL level,
 			 const char *text);
 
+/**
+ * Adds a log message to the referred process dialog and returns immediately.
+ *
+ * This is a convenience function to be used with variable number of arguments (like
+ * printf). It uses the given arguments to prepare a buffer which is then handed to
+ * @ref GWEN_Gui_ProgressLog.
+ * @param id id assigned by @ref GWEN_Gui_ProgressStart (if 0 then the
+ * last started progress dialog is referred to)
+ * @param level log level (see @ref GWEN_Gui_LogLevelPanic ff.)
+ * @param text Text of the box (possibly including printf format string characters): UTF-8, with both a normal text
+ * and a HTML variant of the text in the same string. See text restrictions note above.
+ */
+GWENHYWFAR_API 
+int GWEN_Gui_ProgressLog2(uint32_t id,
+			  GWEN_LOGGER_LEVEL level,
+			  const char *text, ...);
+
 /**
  * <p>
  * Flags the end of the current operation. In graphical user interfaces
@@ -593,7 +634,14 @@ int GWEN_Gui_ProgressLog(uint32_t id,
  * the user will not be able to see the log messages).
  * </p>
  * <p>
- * This function MUST return immediately (non-blocking).
+ * Whether this function is blocking or not depends on the status of the
+ * progress dialog and its initial flags. If the dialog needs to stay open
+ * for the user to read the log messages etc then this function only needs to
+ * return after the user manually closes the dialog.
+ * </p>
+ * <p>
+ * If there is no reason to keep the dialog open then this function should simply
+ * close the dialog window and return immediately.
  * </p>
  * @param id id assigned by @ref GWEN_Gui_ProgressStart (if 0 then the
  * last started progress dialog is referred to)
@@ -700,7 +748,7 @@ int GWEN_Gui_WaitForSockets(GWEN_SOCKET_LIST2 *readSockets,
  */
 GWENHYWFAR_API 
 int GWEN_Gui_CheckCert(const GWEN_SSLCERTDESCR *cert,
-		       GWEN_IO_LAYER *io,
+		       GWEN_SYNCIO *sio,
 		       uint32_t guiid);
 
 
@@ -719,6 +767,76 @@ int GWEN_Gui_KeyDataFromText_OpenSSL(const char *text,
 				     unsigned char *buffer,
 				     unsigned int bufLength);
 
+/**
+ * This function shows and executes the given dialog and returns the result.
+ * See @ref MOD_GUI_DIALOG for a description of the dialog framework.
+ * @param guiid id as returned by @ref GWEN_Gui_ProgressStart, @ref GWEN_Gui_ShowBox or as can be found
+ * via @ref GWEN_Dialog_GetGuiId())
+ * @return <0: error code, 0: aborted, 1: accepted (e.g. "Ok" pressed)
+ */
+GWENHYWFAR_API
+int GWEN_Gui_ExecDialog(GWEN_DIALOG *dlg, uint32_t guiid);
+
+
+
+GWENHYWFAR_API
+int GWEN_Gui_OpenDialog(GWEN_DIALOG *dlg, uint32_t guiid);
+
+GWENHYWFAR_API
+int GWEN_Gui_CloseDialog(GWEN_DIALOG *dlg);
+
+GWENHYWFAR_API
+int GWEN_Gui_RunDialog(GWEN_DIALOG *dlg, int untilEnd);
+
+
+typedef enum {
+  GWEN_Gui_FileNameType_OpenFileName=0,
+  GWEN_Gui_FileNameType_SaveFileName,
+  GWEN_Gui_FileNameType_OpenDirectory
+
+} GWEN_GUI_FILENAME_TYPE;
+
+
+/**
+ * This function is used to get the path and name of a single file or folder.
+ *
+ * @param caption title for the dialog
+ *
+ * @param fnt type of the operation (see @ref GWEN_Gui_FileNameType_OpenFileName and following)
+ *
+ * @param flags currently reserved, use 0
+ *
+ * @param patterns multiple tab-separated entries like in:
+ *   "All Files (*)\tC++ Sources (*.cpp,*.cc)\tC++ Headers (*.hpp,*.hh,*.h)"
+ *
+ * @param pathBuffer upon call this may contain a preselected path/filename, upon return
+ *   this will contain the selected name
+ *
+ * @return 0 if ok, !=0 on error
+ */
+GWENHYWFAR_API
+int GWEN_Gui_GetFileName(const char *caption,
+			 GWEN_GUI_FILENAME_TYPE fnt,
+                         uint32_t flags,
+			 const char *patterns,
+			 GWEN_BUFFER *pathBuffer,
+			 uint32_t guiid);
+
+/**
+ * This function creates a base layer GWEN_SYNCIO.
+ * The idea is to allow applications to implement their own PROXY handling.
+ * @param url url to which the caller wants to connect to. You should call @ref GWEN_Url_fromString()
+ *   to get the information required to determine the protocol and destination.
+ * @param defaultProto default protocol name if not specified by the url (e.g. "http", "https", "hbci")
+ * @param defaultPort default port if not specified by the url
+ * @param pSio pointer to a variable to receive the created GWEN_SYNCIO.
+ */
+GWENHYWFAR_API
+int GWEN_Gui_GetSyncIo(const char *url,
+		       const char *defaultProto,
+		       int defaultPort,
+		       GWEN_SYNCIO **pSio);
+
 
 /*@}*/
 
@@ -737,7 +855,8 @@ int GWEN_Gui_KeyDataFromText_OpenSSL(const char *text,
 #define GWEN_GUI_FLAGS_ACCEPTVALIDCERTS   0x00000002
 /** GUI automatically rejects invalid certs */
 #define GWEN_GUI_FLAGS_REJECTINVALIDCERTS 0x00000004
-
+/** GUI implementation supports dialogs (see @ref MOD_GUI_DIALOG) */
+#define GWEN_GUI_FLAGS_DIALOGSUPPORTED    0x80000000
 
 GWENHYWFAR_API uint32_t GWEN_Gui_GetFlags(const GWEN_GUI *gui);
 GWENHYWFAR_API void GWEN_Gui_SetFlags(GWEN_GUI *gui, uint32_t fl);
@@ -746,6 +865,8 @@ GWENHYWFAR_API void GWEN_Gui_SubFlags(GWEN_GUI *gui, uint32_t fl);
 /*@}*/
 
 
+GWENHYWFAR_API const char *GWEN_Gui_GetName();
+
 
 #ifdef __cplusplus
 }
