@@ -28,6 +28,7 @@
 
 
 #include "gwendate_p.h"
+#include "i18n_l.h"
 
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
@@ -87,6 +88,7 @@ GWEN_DATE *GWEN_Date_fromJulian(int julian) {
   l=j/11;
   gd->month=j+2-(12*l);
   gd->year=100*(n-49)+i+l;
+  gd->julian=julian;
 
   snprintf(gd->asString, sizeof(gd->asString)-1,
 	   "%04d%02d%02d",
@@ -98,12 +100,10 @@ GWEN_DATE *GWEN_Date_fromJulian(int julian) {
 
 
 
-GWEN_DATE *GWEN_Date_CurrentDate() {
-  time_t l;
+GWEN_DATE *GWEN_Date_fromLocalTime(time_t t) {
   struct tm *ltm;
 
-  time(&l);
-  ltm=localtime(&l);
+  ltm=localtime(&t);
   if (ltm) {
     GWEN_DATE *gd;
 
@@ -116,6 +116,32 @@ GWEN_DATE *GWEN_Date_CurrentDate() {
 
 
 
+GWEN_DATE *GWEN_Date_fromGmTime(time_t t) {
+  struct tm *ltm;
+
+  ltm=gmtime(&t);
+  if (ltm) {
+    GWEN_DATE *gd;
+
+    gd=GWEN_Date_fromGregorian(ltm->tm_year+1900, ltm->tm_mon+1, ltm->tm_mday);
+    return gd;
+  }
+
+  return NULL;
+}
+
+
+
+
+GWEN_DATE *GWEN_Date_CurrentDate() {
+  time_t l;
+
+  time(&l);
+  return GWEN_Date_fromLocalTime(l);
+}
+
+
+
 GWEN_DATE *GWEN_Date_dup(const GWEN_DATE *ogd) {
   assert(ogd);
   return GWEN_Date_fromGregorian(ogd->year, ogd->month, ogd->day);
@@ -373,6 +399,15 @@ GWEN_DATE_TMPLCHAR *GWEN_DateTmplChar_new(char c) {
   GWEN_NEW_OBJECT(GWEN_DATE_TMPLCHAR, e);
   GWEN_LIST_INIT(GWEN_DATE_TMPLCHAR, e);
   e->character=c;
+  switch(c) {
+  case 'Y': e->maxCount=4; break;
+  case 'M': e->maxCount=2; break;
+  case 'D': e->maxCount=2; break;
+  case 'W': e->maxCount=1; break;
+  case 'w':
+  default:  e->maxCount=GWEN_DATE_TMPL_MAX_COUNT; break;
+  }
+
   return e;
 }
 
@@ -411,7 +446,7 @@ void GWEN_Date__sampleTmplChars(GWEN_UNUSED const GWEN_DATE *t, const char *tmpl
 
   s=tmpl;
   while(*s) {
-    if (strchr("YMD", *s)) {
+    if (strchr("YMDWw", *s)) {
       GWEN_DATE_TMPLCHAR *e;
 
       e=GWEN_Date__findTmplChar(ll, *s);
@@ -440,23 +475,59 @@ void GWEN_Date__fillTmplChars(const GWEN_DATE *t, GWEN_DATE_TMPLCHAR_LIST *ll) {
   e=GWEN_DateTmplChar_List_First(ll);
   while(e) {
     int v;
-    char buffer[32];
 
-    switch(e->character) {
-    case 'Y': v=t->year; break;
-    case 'M': v=t->month; break;
-    case 'D': v=t->day; break;
-    default:  v=-1; break;
+    if (e->character=='w') {
+      const char *s=NULL;
+
+      switch(GWEN_Date_WeekDay(t)) {
+      case 0:  s=I18N("Sunday"); break;
+      case 1:  s=I18N("Monday"); break;
+      case 2:  s=I18N("Tuesday"); break;
+      case 3:  s=I18N("Wednesday"); break;
+      case 4:  s=I18N("Thursday"); break;
+      case 5:  s=I18N("Friday"); break;
+      case 6:  s=I18N("Saturday"); break;
+      }
+      assert(s);
+      e->content=strdup(s);
+      e->nextChar=0;
     }
-    if (v==-1) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "Unknown character, should not happen here");
-      abort();
+    else {
+      char buffer[32];
+      int clen;
+
+      switch(e->character) {
+      case 'Y':
+        v=t->year;
+        break;
+      case 'M':
+        v=t->month;
+        break;
+      case 'D':
+        v=t->day;
+        break;
+      case 'W':
+        v=GWEN_Date_WeekDay(t);
+        break;
+      default:
+        v=-1;
+        break;
+      }
+      if (v==-1) {
+        DBG_ERROR(GWEN_LOGDOMAIN, "Unknown character, should not happen here");
+        abort();
+      }
+      buffer[0]=0;
+      snprintf(buffer, sizeof(buffer)-1, "%0*d", e->maxCount, v);
+      buffer[sizeof(buffer)-1]=0;
+      e->content=strdup(buffer);
+      /* adjust counter if there are more than maxCount template chars */
+      clen=strlen(e->content);
+      if (e->count>clen)
+        e->count=clen;
+      e->nextChar=clen-(e->count);
     }
-    buffer[0]=0;
-    snprintf(buffer, sizeof(buffer)-1, "%0*d", GWEN_DATE_TMPL_MAX_COUNT, v);
-    buffer[sizeof(buffer)-1]=0;
-    e->content=strdup(buffer);
-    e->nextChar=strlen(e->content)-(e->count);
+
     e=GWEN_DateTmplChar_List_Next(e);
   }
 }
@@ -474,16 +545,26 @@ int GWEN_Date_toStringWithTemplate(const GWEN_DATE *t, const char *tmpl, GWEN_BU
 
   s=tmpl;
   while(*s) {
-    if (strchr("YMD", *s)) {
+    if (strchr("YMDWw", *s)) {
       GWEN_DATE_TMPLCHAR *e;
       char c;
 
       e=GWEN_Date__findTmplChar(ll, *s);
       assert(e);
       assert(e->content);
-      c=e->content[e->nextChar++];
-      assert(c);
-      GWEN_Buffer_AppendByte(buf, c);
+      if (s[1]=='*') {
+        /* append full string */
+        GWEN_Buffer_AppendString(buf, e->content);
+        /* skip asterisk */
+        s++;
+      }
+      else {
+        c=e->content[e->nextChar];
+        if (c!=0) {
+          GWEN_Buffer_AppendByte(buf, c);
+          e->nextChar++;
+        }
+      }
     }
     else
       GWEN_Buffer_AppendByte(buf, *s);
