@@ -36,6 +36,8 @@ typedef struct GWEN_DATE GWEN_DATE;
 
 #include <gwenhywfar/gwentime.h>
 
+#include <time.h>
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -69,6 +71,10 @@ GWENHYWFAR_API GWEN_DATE *GWEN_Date_dup(const GWEN_DATE *ogd);
 
 GWENHYWFAR_API GWEN_DATE *GWEN_Date_fromTime(const GWEN_TIME *ti);
 
+GWENHYWFAR_API GWEN_DATE *GWEN_Date_fromLocalTime(time_t t);
+GWENHYWFAR_API GWEN_DATE *GWEN_Date_fromGmTime(time_t t);
+
+
 GWENHYWFAR_API GWEN_DATE *GWEN_Date_fromStringWithTemplate(const char *s, const char *tmpl);
 GWENHYWFAR_API int GWEN_Date_toStringWithTemplate(const GWEN_DATE *t,
 						  const char *tmpl,
@@ -87,6 +93,10 @@ GWENHYWFAR_API const char *GWEN_Date_GetString(const GWEN_DATE *gd);
 
 GWENHYWFAR_API int GWEN_Date_DaysInMonth(const GWEN_DATE *gd);
 
+/**
+ * Returns the distance between the given date and the begin of that year.
+ * E.g. if the given date is the 1st of January the result is 0.
+ */
 GWENHYWFAR_API int GWEN_Date_DaysInYear(const GWEN_DATE *gd);
 
 GWENHYWFAR_API int GWEN_Date_GetYear(const GWEN_DATE *gd);
