@@ -304,6 +304,8 @@ GWEN_TIME *GWEN_Time__fromString(const char *s, const char *tmpl, int inUtc){
 
   if (year<100)
     year+=2000;
+  if (day==0)
+    day=1;
 
   DBG_DEBUG(GWEN_LOGDOMAIN,
 	    "Got this date/time: %04d/%02d/%02d, %02d:%02d:%02d",
@@ -744,9 +746,17 @@ int GWEN_Time__toString(const GWEN_TIME *t, const char *tmpl,
       e=GWEN_Time__findTmplChar(ll, *s);
       assert(e);
       assert(e->content);
-      c=e->content[e->nextChar++];
-      assert(c);
-      GWEN_Buffer_AppendByte(buf, c);
+      if (s[1]=='*') {
+        /* append full string */
+        GWEN_Buffer_AppendString(buf, e->content);
+        /* skip asterisk */
+        s++;
+      }
+      else {
+        c=e->content[e->nextChar++];
+        assert(c);
+        GWEN_Buffer_AppendByte(buf, c);
+      }
     }
     else
       GWEN_Buffer_AppendByte(buf, *s);
