@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Tue Dec 03 2002
-    copyright   : (C) 2002 by Martin Preuss
+    copyright   : (C) 2002-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -32,6 +29,7 @@
 #include "directory_p.h"
 #if defined(OS_DARWIN) && defined(ENABLE_LOCAL_INSTALL)
 #  include <CoreFoundation/CFBundle.h>
+#  include <sys/param.h>
 #else
 # include "binreloc.h"
 #endif
@@ -199,21 +197,70 @@ int GWEN_Directory_CreatePublic(const char *path){
 
 
 int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size){
+#ifdef OS_DARWIN
+# ifdef ENABLE_LOCAL_INSTALL
+  char binarypath[1024];
+  char realbuffer[PATH_MAX];
+  uint32_t pathsize = sizeof(binarypath);
+  char *s;
+
+  if (_NSGetExecutablePath(binarypath, &pathsize)==-1) {
+    DBG_ERROR(GWEN_LOGDOMAIN,
+	      "Unable to determine exe folder (error on _NSGetExecutablePath)");
+    return GWEN_ERROR_GENERIC;
+  }
+  DBG_INFO(GWEN_LOGDOMAIN, "Binary path: [%s]", binarypath);
+  if (NULL==realpath(binarypath, realbuffer)) {
+    DBG_ERROR(GWEN_LOGDOMAIN,
+	      "Unable to determine real exe folder (error on realpath)");
+    return GWEN_ERROR_GENERIC;
+  }
+
+  /* remove binary name */
+  s=strrchr(realbuffer, '/');
+  if (s==NULL) {
+    DBG_ERROR(GWEN_LOGDOMAIN,
+	      "Bad path returned by system: [%s]", realbuffer);
+    return GWEN_ERROR_GENERIC;
+  }
+  if (s) {
+    *s=0;
+
+    /* remove "/bin/" or "MacOS" from path */
+    s=strrchr(realbuffer, '/');
+    if (s) {
+      if (strcasecmp(s, "/bin")==0 ||
+	  strcasecmp(s, "/MacOS")==0)
+	*s=0;
+    }
+  }
+
+  if ((strlen(realbuffer)+1)>=size) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer too small");
+    return GWEN_ERROR_BUFFER_OVERFLOW;
+  }
+
+  strcpy(buffer, realbuffer);
+  return 0;
+
+# else /* not local install */
+
+  const char *s="/usr/local";
+
+  if ((strlen(s)+1)>=size) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer too small");
+    return GWEN_ERROR_BUFFER_OVERFLOW;
+  }
+  strcpy(buffer, s);
+  return 0;
+
+# endif
+#else /* if darwin */
+
+# ifdef ENABLE_BINRELOC
   char *exeDir;
 
-#if defined(OS_DARWIN) && defined(ENABLE_LOCAL_INSTALL)
-  CFBundleRef mainBundle = CFBundleGetMainBundle() ;
-  CFURLRef resourcesURL = CFBundleCopyResourcesDirectoryURL(mainBundle);
-  CFStringRef resourcesPath = CFURLCopyFileSystemPath(resourcesURL, kCFURLPOSIXPathStyle) ;
-  CFIndex maxPathSize = CFStringGetMaximumSizeOfFileSystemRepresentation(resourcesPath);
-  if ((exeDir = malloc(maxPathSize * sizeof(char)))) {
-    CFStringGetFileSystemRepresentation(resourcesPath, exeDir , maxPathSize);
-  }
-  CFRelease(resourcesPath);
-  CFRelease(resourcesURL);
-#else
   exeDir=br_find_prefix(NULL);
-#endif
   if (exeDir==(char*)NULL) {
     DBG_INFO(GWEN_LOGDOMAIN,
 	     "Unable to determine exe folder");
@@ -228,6 +275,19 @@ int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size){
   strcpy(buffer, exeDir);
   free(exeDir);
   return 0;
+
+# else /* if with binloc */
+  const char *s="/usr/local";
+
+  if ((strlen(s)+1)>=size) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer too small");
+    return GWEN_ERROR_BUFFER_OVERFLOW;
+  }
+  strcpy(buffer, s);
+  return 0;
+
+# endif /* if without binloc */
+#endif /* if not darwin */
 }
 
 
