@@ -521,15 +521,6 @@ int GWEN_Socket_Write(GWEN_SOCKET *sp, const char *buffer, int *bsize){
   assert(buffer);
   assert(bsize);
 
-#ifdef OS_DARWIN
-  /* this is just a temporary ugly hack for OS X, this has to be investigated
-   * further */
-  if (sp->haveWaited==0) {
-    sleep(1);
-    sp->haveWaited=1;
-  }
-#endif
-
   i=send(sp->socket,
 	 buffer,
 	 *bsize,
