@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Tue Sep 09 2003
- copyright   : (C) 2003 by Martin Preuss
+ copyright   : (C) 2003-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -36,14 +33,12 @@
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/path.h>
-#include <gwenhywfar/bufferedio.h>
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/dbio.h>
 #include <gwenhywfar/fslock.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/io_memory.h>
-#include <gwenhywfar/iomanager.h>
 #include <gwenhywfar/fastbuffer.h>
+#include <gwenhywfar/syncio_file.h>
+#include <gwenhywfar/syncio_memory.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -247,19 +242,8 @@ void GWEN_DB_Node_free(GWEN_DB_NODE *n){
     GWEN_LIST_FINI(GWEN_DB_NODE, n);
 
     /* free children */
-    if (n->children) {
-      GWEN_DB_NODE *cn;
-
-      cn=GWEN_DB_Node_List_First(n->children);
-      while(cn) {
-	GWEN_DB_NODE *ncn;
-
-	ncn=GWEN_DB_Node_List_Next(cn);
-	DBG_VERBOUS(GWEN_LOGDOMAIN, "Freeing child node");
-	GWEN_DB_Node_free(cn);
-	cn=ncn;
-      }
-    }
+    if (n->children)
+      GWEN_DB_Node_List_free(n->children);
 
     /* free dynamic (allocated) data */
     switch(n->typ) {
@@ -1276,26 +1260,26 @@ const char *GWEN_DB_GroupName(GWEN_DB_NODE *n){
 
 
 
-void GWEN_DB_Dump(GWEN_DB_NODE *n, FILE *f, int insert){
+void GWEN_DB_Dump(GWEN_DB_NODE *n, int insert){
   if (n) {
     int i;
 
     for (i=0; i<insert; i++)
-      fprintf(f, " ");
+      fprintf(stderr, " ");
 
     /* dump dynamic (allocated) data */
     switch(n->typ) {
     case GWEN_DB_NodeType_Group:
-      fprintf(f, "Group : \"%s\"\n", n->data.dataName);
+      fprintf(stderr, "Group : \"%s\"\n", n->data.dataName);
       break;
     case GWEN_DB_NodeType_Var:
-      fprintf(f, "Var   : \"%s\"\n", n->data.dataName);
+      fprintf(stderr, "Var   : \"%s\"\n", n->data.dataName);
       break;
     case GWEN_DB_NodeType_ValueChar:
-      fprintf(f, "Value : \"%s\" (char)\n", n->data.dataChar);
+      fprintf(stderr, "Value : \"%s\" (char)\n", n->data.dataChar);
       break;
     case GWEN_DB_NodeType_ValueInt:
-      fprintf(f, "Value : %d (int)\n", n->data.dataInt);
+      fprintf(stderr, "Value : %d (int)\n", n->data.dataInt);
       break;
     case GWEN_DB_NodeType_ValueBin: {
       char *buffer;
@@ -1304,19 +1288,19 @@ void GWEN_DB_Dump(GWEN_DB_NODE *n, FILE *f, int insert){
       assert(buffer);
       if (GWEN_Text_ToHex(n->data.dataBin, n->dataSize,
 			  buffer, (n->dataSize*2)+1)==0) {
-	fprintf(f, "Value : %d bytes (bin)\n", n->dataSize);
+	fprintf(stderr, "Value : %d bytes (bin)\n", n->dataSize);
       }
       else {
-	fprintf(f, "Value : %s (bin)\n", buffer);
+	fprintf(stderr, "Value : %s (bin)\n", buffer);
       }
       GWEN_Memory_dealloc(buffer);
       break;
     }
     case GWEN_DB_NodeType_ValuePtr:
-      fprintf(f, "Value : %p (ptr)\n", n->data.dataPtr);
+      fprintf(stderr, "Value : %p (ptr)\n", n->data.dataPtr);
       break;
     default:
-      fprintf(f, "[unknown node type %d]\n", n->typ);
+      fprintf(stderr, "[unknown node type %d]\n", n->typ);
     }
 
     /* dump children */
@@ -1325,13 +1309,13 @@ void GWEN_DB_Dump(GWEN_DB_NODE *n, FILE *f, int insert){
 
       cn=GWEN_DB_Node_List_First(n->children);
       while(cn) {
-	GWEN_DB_Dump(cn, f, insert+4);
+	GWEN_DB_Dump(cn, insert+4);
 	cn=GWEN_DB_Node_List_Next(cn);
       }
     }
   }
   else {
-    fprintf(f, "[no node]\n");
+    fprintf(stderr, "[no node]\n");
   }
 }
 
@@ -1390,7 +1374,7 @@ int GWEN_DB_AddGroupChildren(GWEN_DB_NODE *n, GWEN_DB_NODE *nn){
 
   if (nn->typ!=GWEN_DB_NodeType_Group) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Source node is not a group");
-    GWEN_DB_Dump(nn, stderr, 1);
+    GWEN_DB_Dump(nn, 1);
     return -1;
   }
 
