@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: tag16.c 1113 2007-01-10 09:14:16Z martin $
     begin       : Sun Jun 13 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -15,6 +12,9 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
+
 #include "tag16_p.h"
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/inherit.h>
