@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -29,6 +26,9 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
+
 #include "text.h"
 #include <stdlib.h>
 #include <assert.h>
@@ -1037,6 +1037,39 @@ int GWEN_Text_Compare(const char *s1, const char *s2, int ign) {
 
 
 
+const char *GWEN_Text_StrCaseStr(const char *haystack, const char *needle) {
+  while(*haystack) {
+    while(*haystack && tolower(*haystack)!=tolower(*needle))
+      haystack++;
+    if (*haystack) {
+      const char *t;
+      const char *s;
+
+      /* now haystack points to an area which begins with *needle */
+      t=haystack;
+      s=needle;
+      t++;
+      s++;
+      while(*t && *s && (tolower(*t)==tolower(*s))) {
+	t++;
+	s++;
+      }
+      if (*s==0)
+	return haystack;
+    }
+    else
+      /* not found */
+      break;
+    /* no match here, advance haystack */
+    haystack++;
+  }
+
+  /* not found */
+  return NULL;
+}
+
+
+
 
 int GWEN_Text__cmpSegment(const char *w, unsigned int *wpos,
                           const char *p, unsigned int *ppos,
@@ -1200,7 +1233,7 @@ int GWEN_Text_NumToString(int num, char *buffer, unsigned int bufsize,
 
 
 void GWEN_Text_DumpString(const char *s, unsigned int l,
-                          FILE *f, unsigned int insert) {
+                          unsigned int insert) {
   unsigned int i;
   unsigned int j;
   unsigned int pos;
@@ -1208,31 +1241,31 @@ void GWEN_Text_DumpString(const char *s, unsigned int l,
 
   pos=0;
   for (k=0; k<insert; k++)
-    fprintf(f, " ");
-  fprintf(f,"String size is %d:\n",l);
+    fprintf(stderr, " ");
+  fprintf(stderr,"String size is %d:\n",l);
   while(pos<l) {
     for (k=0; k<insert; k++)
-      fprintf(f, " ");
-    fprintf(f,"%04x: ",pos);
+      fprintf(stderr, " ");
+    fprintf(stderr,"%04x: ",pos);
     j=pos+16;
     if (j>=l)
       j=l;
 
     /* show hex dump */
     for (i=pos; i<j; i++) {
-      fprintf(f,"%02x ",(unsigned char)s[i]);
+      fprintf(stderr,"%02x ",(unsigned char)s[i]);
     }
     if (j-pos<16)
       for (i=0; i<16-(j-pos); i++)
-	fprintf(f,"   ");
+	fprintf(stderr,"   ");
     /* show text */
     for (i=pos; i<j; i++) {
       if (s[i]<32)
-	fprintf(f,".");
+	fprintf(stderr,".");
       else
-	fprintf(f,"%c",s[i]);
+	fprintf(stderr,"%c",s[i]);
     }
-    fprintf(f,"\n");
+    fprintf(stderr,"\n");
     pos+=16;
   }
 }
@@ -1742,7 +1775,7 @@ int GWEN_Text_CountUtf8Chars(const char *s, int len) {
     if (i) {
       int j;
 
-      for (j=0; j<j; j++) {
+      for (j=0; j<i; j++) {
         if ((((unsigned char)*s) & 0xc0)!=0xc0) {
           DBG_ERROR(GWEN_LOGDOMAIN,
                     "Invalid UTF8 sequence at pos %d (rel %d of %d)",
@@ -1792,11 +1825,12 @@ int GWEN_Text_UnescapeXmlToBuffer(const char *src, GWEN_BUFFER *buf) {
     match=0;
     x=(unsigned char)*src;
     if (x=='&') {
-      if (0 && src[1]=='#') { /* disabled */
+      if (src[1]=='#') {
 	unsigned char num=0;
 
 	src++;
-	while(isdigit((int)*src)) {
+	src++;
+	while(*src && isdigit((int)*src)) {
 	  num*=10;
 	  num+=(*src)-'0';
 	  src++;
@@ -1804,6 +1838,48 @@ int GWEN_Text_UnescapeXmlToBuffer(const char *src, GWEN_BUFFER *buf) {
         src++;
 	GWEN_TEXT__APPENDCHAR(num);
       }
+      else if (strncmp(src+1, "szlig;", 6)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0x9f);
+        src+=7;
+	match=1;
+      }
+      else if (strncmp(src+1, "Auml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0x84);
+        src+=6;
+	match=1;
+      }
+      else if (strncmp(src+1, "Ouml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0x96);
+        src+=6;
+	match=1;
+      }
+      else if (strncmp(src+1, "Uuml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0x9c);
+        src+=6;
+	match=1;
+      }
+      else if (strncmp(src+1, "auml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0xa4);
+        src+=6;
+	match=1;
+      }
+      else if (strncmp(src+1, "ouml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0xb6);
+        src+=6;
+	match=1;
+      }
+      else if (strncmp(src+1, "uuml;", 5)==0) {
+	GWEN_TEXT__APPENDCHAR(0xc3);
+	GWEN_TEXT__APPENDCHAR(0xbc);
+        src+=6;
+	match=1;
+      }
       else {
 	const GWEN_TEXT_ESCAPE_ENTRY *e;
 	e=gwen_text__xml_escape_chars;
@@ -1875,11 +1951,3 @@ int GWEN_Text_EscapeXmlToBuffer(const char *src, GWEN_BUFFER *buf) {
 
 
 
-
-
-
-
-
-
-
-
