@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -250,6 +247,14 @@ GWENHYWFAR_API
 int GWEN_Text_Compare(const char *s1, const char *s2, int ign);
 
 
+/**
+ * This function provides the functionality of strcasestr() which is not available
+ * on some systems.
+ */
+GWENHYWFAR_API
+const char *GWEN_Text_StrCaseStr(const char *haystack, const char *needle);
+
+
 /**
  * This function compares two string and returns the number of matches or
  * -1 on error.
@@ -266,7 +271,7 @@ int GWEN_Text_ComparePattern(const char *w, const char *p, int sensecase);
  * classical hexdump.
  */
 GWENHYWFAR_API
-void GWEN_Text_DumpString(const char *s, unsigned int l, FILE *f,
+void GWEN_Text_DumpString(const char *s, unsigned int l,
                           unsigned int insert);
 
 
