@@ -58,6 +58,7 @@ void Typemaker2_Builder_free(TYPEMAKER2_BUILDER *tb) {
     free(tb->fileNameProtected);
     free(tb->fileNamePrivate);
     free(tb->fileNameCode);
+    free(tb->destFolder);
     GWEN_FREE_OBJECT(tb);
   }
 }
@@ -244,6 +245,22 @@ void Typemaker2_Builder_SetSourceFileName(TYPEMAKER2_BUILDER *tb, const char *s)
 
 
 
+const char *Typemaker2_Builder_GetDestFolderName(const TYPEMAKER2_BUILDER *tb) {
+  assert(tb);
+  return tb->destFolder;
+}
+
+
+
+void Typemaker2_Builder_SetDestFolderName(TYPEMAKER2_BUILDER *tb, const char *s) {
+  assert(tb);
+  free(tb->destFolder);
+  if (s) tb->destFolder=strdup(s);
+  else tb->destFolder=NULL;
+}
+
+
+
 void Typemaker2_Builder_SetBuildFn(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_BUILDER_BUILD_FN fn) {
   assert(tb);
   tb->buildFn=fn;
@@ -677,6 +694,30 @@ int Typemaker2_Builder_WriteFile(TYPEMAKER2_BUILDER *tb,
     se=GWEN_StringListEntry_Next(se);
   }
 
+  if (acc==TypeMaker2_Access_Unknown) {
+    TYPEMAKER2_HEADER_LIST *hl;
+
+    /* write codeEnd headers */
+    fprintf(f, "\n");
+    fprintf(f, "/* code headers */\n");
+    hl=Typemaker2_Type_GetHeaders(ty);
+    if (hl) {
+      TYPEMAKER2_HEADER *h;
+
+      h=Typemaker2_Header_List_First(hl);
+      while(h) {
+	if (Typemaker2_Header_GetLocation(h)==Typemaker2_HeaderLocation_CodeEnd) {
+          if (Typemaker2_Header_GetType(h)==Typemaker2_HeaderType_System)
+	    fprintf(f, "#include <%s>\n", Typemaker2_Header_GetFileName(h));
+          else
+	    fprintf(f, "#include \"%s\"\n", Typemaker2_Header_GetFileName(h));
+	}
+	h=Typemaker2_Header_List_Next(h);
+      }
+    }
+    fprintf(f, "\n");
+  }
+
   if (acc!=TypeMaker2_Access_Unknown) {
     fprintf(f, "#ifdef __cplusplus\n}\n#endif\n\n");
     fprintf(f, "#endif\n\n");
@@ -819,6 +860,49 @@ int Typemaker2_Builder_WriteTypedefFile_List2(TYPEMAKER2_BUILDER *tb,
 
 
 
+int Typemaker2_Builder_WriteTypedefFile_Tree(TYPEMAKER2_BUILDER *tb,
+					     TYPEMAKER2_TYPE *ty,
+					     const char *fileName) {
+  FILE *f;
+
+  f=fopen(fileName, "w");
+  if (f==NULL) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "fopen(%s): %s (%d)",
+	      fileName,
+	      strerror(errno),
+	      errno);
+    return GWEN_ERROR_IO;
+  }
+
+  fprintf(f, "<?xml?>\n");
+  fprintf(f, "\n");
+  fprintf(f, "<tm2>\n");
+
+  fprintf(f, "  <typedef id=\"%s_TREE\" type=\"pointer\" lang=\"c\" extends=\"tree_base\" "
+	  "basetype=\"%s\">\n",
+	  Typemaker2_Type_GetName(ty),
+	  Typemaker2_Type_GetName(ty));
+
+  fprintf(f, "    <identifier>%s_TREE</identifier>\n", Typemaker2_Type_GetName(ty));
+  fprintf(f, "    <prefix>%s_Tree</prefix>\n", Typemaker2_Type_GetPrefix(ty));
+
+  fprintf(f, "  </typedef>\n");
+  fprintf(f, "</tm2>\n");
+
+  if (fclose(f)) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "fclose(%s): %s (%d)",
+	      fileName,
+	      strerror(errno),
+	      errno);
+    return GWEN_ERROR_IO;
+  }
+
+  return 0;
+}
+
+
+
+
 
 int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty) {
   const char *fname;
@@ -839,6 +923,10 @@ int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_
 	}
       }
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+      if (tb->destFolder) {
+	GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+      }
       GWEN_Buffer_AppendString(tbuf, s);
       t=GWEN_Buffer_GetStart(tbuf);
       while(*t) {
@@ -868,6 +956,10 @@ int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_
 	}
       }
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+      if (tb->destFolder) {
+	GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+      }
       GWEN_Buffer_AppendString(tbuf, s);
       t=GWEN_Buffer_GetStart(tbuf);
       while(*t) {
@@ -897,6 +989,10 @@ int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_
 	}
       }
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+      if (tb->destFolder) {
+	GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+      }
       GWEN_Buffer_AppendString(tbuf, s);
       t=GWEN_Buffer_GetStart(tbuf);
       while(*t) {
@@ -926,6 +1022,10 @@ int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_
 	}
       }
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+      if (tb->destFolder) {
+	GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+      }
       GWEN_Buffer_AppendString(tbuf, s);
       t=GWEN_Buffer_GetStart(tbuf);
       while(*t) {
@@ -955,6 +1055,10 @@ int Typemaker2_Builder_DetermineOutFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_
 	}
       }
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+      if (tb->destFolder) {
+	GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+      }
       GWEN_Buffer_AppendString(tbuf, s);
       t=GWEN_Buffer_GetStart(tbuf);
       while(*t) {
@@ -1055,6 +1159,10 @@ int Typemaker2_Builder_WriteFiles(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty) {
 	return GWEN_ERROR_BAD_DATA;
     }
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    if (tb->destFolder) {
+      GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+      GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+    }
     GWEN_Buffer_AppendString(tbuf, s);
     t=GWEN_Buffer_GetStart(tbuf);
     while(*t) {
@@ -1084,6 +1192,10 @@ int Typemaker2_Builder_WriteFiles(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty) {
 	return GWEN_ERROR_BAD_DATA;
     }
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    if (tb->destFolder) {
+      GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+      GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+    }
     GWEN_Buffer_AppendString(tbuf, s);
     t=GWEN_Buffer_GetStart(tbuf);
     while(*t) {
@@ -1112,6 +1224,10 @@ int Typemaker2_Builder_WriteFiles(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty) {
 	return GWEN_ERROR_BAD_DATA;
     }
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    if (tb->destFolder) {
+      GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+      GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+    }
     GWEN_Buffer_AppendString(tbuf, s);
     t=GWEN_Buffer_GetStart(tbuf);
     while(*t) {
@@ -1128,6 +1244,37 @@ int Typemaker2_Builder_WriteFiles(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty) {
     }
   }
 
+  /* write typedef file for tree */
+  if (Typemaker2_Type_GetFlags(ty) & TYPEMAKER2_FLAGS_WITH_TREE) {
+    const char *s;
+    char *t;
+    GWEN_BUFFER *tbuf;
+
+    s=Typemaker2_Type_GetName(ty);
+    if (s==NULL || *s==0) {
+	DBG_ERROR(GWEN_LOGDOMAIN, "Type has no name");
+	return GWEN_ERROR_BAD_DATA;
+    }
+    tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    if (tb->destFolder) {
+      GWEN_Buffer_AppendString(tbuf, tb->destFolder);
+      GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+    }
+    GWEN_Buffer_AppendString(tbuf, s);
+    t=GWEN_Buffer_GetStart(tbuf);
+    while(*t) {
+      *t=tolower(*t);
+      t++;
+    }
+    GWEN_Buffer_AppendString(tbuf, "_tree.tm2");
+    fname=GWEN_Buffer_GetStart(tbuf);
+    rv=Typemaker2_Builder_WriteTypedefFile_Tree(tb, ty, fname);
+    GWEN_Buffer_free(tbuf);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
 
 
   return 0;
